@@ -6,7 +6,7 @@ package Mite::Compiled;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007000';
+our $VERSION   = '0.007001';
 
 use Path::Tiny;
 
@@ -14,7 +14,7 @@ use Path::Tiny;
 
 has file =>
   is            => rw,
-  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),
+  isa           => Path,
   coerce        => true,
   lazy          => true,
   default       => sub {
