@@ -6,7 +6,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.007000";
+    our $MITE_VERSION = "0.007001";
 
     BEGIN {
         require Scalar::Util;
@@ -61,6 +61,28 @@
                       ? scalar(
                         do { local $_ = $to_coerce; Path::Tiny::path($_) }
                       )
+                      : (
+                        do {
+
+                            package Mite::Shim;
+                            defined($to_coerce) && !ref($to_coerce)
+                              or Scalar::Util::blessed($to_coerce) && (
+                                sub {
+                                    require overload;
+                                    overload::Overloaded( ref $_[0] or $_[0] )
+                                      and
+                                      overload::Method( ( ref $_[0] or $_[0] ),
+                                        $_[1] );
+                                }
+                            )->( $to_coerce, q[""] );
+                        }
+                      )
+                      ? scalar(
+                        do { local $_ = $to_coerce; Path::Tiny::path($_) }
+                      )
+                      : ( ( ref($to_coerce) eq 'ARRAY' ) ) ? scalar(
+                        do { local $_ = $to_coerce; Path::Tiny::path(@$_) }
+                      )
                       : $to_coerce;
                 };
                 (
@@ -192,6 +214,27 @@
                   ? scalar(
                     do { local $_ = $to_coerce; Path::Tiny::path($_) }
                   )
+                  : (
+                    do {
+
+                        package Mite::Shim;
+                        defined($to_coerce) && !ref($to_coerce)
+                          or Scalar::Util::blessed($to_coerce) && (
+                            sub {
+                                require overload;
+                                overload::Overloaded( ref $_[0] or $_[0] )
+                                  and overload::Method( ( ref $_[0] or $_[0] ),
+                                    $_[1] );
+                            }
+                        )->( $to_coerce, q[""] );
+                    }
+                  )
+                  ? scalar(
+                    do { local $_ = $to_coerce; Path::Tiny::path($_) }
+                  )
+                  : ( ( ref($to_coerce) eq 'ARRAY' ) ) ? scalar(
+                    do { local $_ = $to_coerce; Path::Tiny::path(@$_) }
+                  )
                   : $to_coerce;
             };
             (
@@ -239,6 +282,36 @@
                                     Path::Tiny::path($_);
                                 }
                               )
+                              : (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($to_coerce) && !ref($to_coerce)
+                                      or Scalar::Util::blessed($to_coerce) && (
+                                        sub {
+                                            require overload;
+                                            overload::Overloaded(
+                                                ref $_[0]
+                                                  or $_[0]
+                                              )
+                                              and overload::Method(
+                                                ( ref $_[0] or $_[0] ), $_[1] );
+                                        }
+                                    )->( $to_coerce, q[""] );
+                                }
+                              )
+                              ? scalar(
+                                do {
+                                    local $_ = $to_coerce;
+                                    Path::Tiny::path($_);
+                                }
+                              )
+                              : ( ( ref($to_coerce) eq 'ARRAY' ) ) ? scalar(
+                                do {
+                                    local $_ = $to_coerce;
+                                    Path::Tiny::path(@$_);
+                                }
+                              )
                               : $to_coerce;
                         };
                         (
