@@ -6,7 +6,7 @@ package Mite::Config;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007000';
+our $VERSION   = '0.007001';
 
 has mite_dir_name =>
   is            => ro,
@@ -15,7 +15,7 @@ has mite_dir_name =>
 
 has mite_dir =>
   is            => ro,
-  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),
+  isa           => Path,
   coerce        => true,
   lazy          => true,
   default       => sub {
@@ -26,7 +26,7 @@ has mite_dir =>
 
 has config_file =>
   is            => ro,
-  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),
+  isa           => Path,
   coerce        => true,
   lazy          => true,
   default       => sub {
