@@ -5,14 +5,11 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007000';
+our $VERSION   = '0.007001';
 
 use Import::Into;
 use Mite::Shim ();
 use Mite::Types ();
-use Types::Standard ();
-use Types::Common::String ();
-use Types::Path::Tiny ();
 use Type::Params ();
 
 sub import {
@@ -49,17 +46,8 @@ sub to_import {
 	no warnings 'uninitialized';
 	return (
 		[ 'Mite::Types' => [
-			qw( -types ),
-		] ],
-		[ 'Types::Standard' => [
 			qw( -types slurpy ),
 		] ],
-		[ 'Types::Common::String' => [
-			qw( -types ),
-		] ],
-		[ 'Types::Path::Tiny' => [
-			qw( -types ),
-		] ],
 		[ 'Type::Params' => [
 			compile           => { -as => 'sig_pos'   },
 			compile_named_oo  => { -as => 'sig_named' },
