@@ -6,11 +6,11 @@ package Mite::Source;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007000';
+our $VERSION   = '0.007001';
 
 has file =>
   is            => ro,
-  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),,
+  isa           => Path,
   coerce        => true,
   required      => true;
 
